@@ -25,9 +25,7 @@ class WelcomeController(WelcomeControllerBase):
     def welcome(self):
         title = "Ubuntu Core"
         excerpt = ("Configure the network and setup an administrator "
-                   "account on this all-snap Ubuntu Core system. After "
-                   "this setup process you will have secure web or command "
-                   "access to the system.")
+                   "account on this all-snap Ubuntu Core system.")
         self.ui.set_header(title, excerpt)
         self.ui.set_footer("")
         view = WelcomeView(self.model, self.signal)
