@@ -20,7 +20,7 @@ from urwid import (Pile, Columns, Text, ListBox)
 from subiquitycore.ui.buttons import done_btn, cancel_btn
 from subiquitycore.ui.interactive import EmailEditor
 from subiquitycore.ui.utils import Padding, Color
-from subiquitycore.utils import run_command
+from subiquitycore.utils import run_command, mark_firstboot_complete
 from subiquitycore.view import BaseView
 
 log = logging.getLogger("console_conf.views.identity")
@@ -46,6 +46,20 @@ log = logging.getLogger("console_conf.views.identity")
 +---------------------------------------------------+
 '''
 
+class SubmittingEmailEditor(EmailEditor):
+
+    def __init__(self, mainview):
+        self.mainview = mainview
+        super().__init__(caption="")
+
+    def keypress(self, size, key):
+        if key == 'enter':
+            self.mainview.done(None)
+            return None
+        else:
+            return super().keypress(size, key)
+
+
 class IdentityView(BaseView):
 
     def __init__(self, model, signal, opts, loop):
@@ -54,7 +68,7 @@ class IdentityView(BaseView):
         self.opts = opts
         self.loop = loop
         self.items = []
-        self.email = EmailEditor(caption="")
+        self.email = SubmittingEmailEditor(self)
         self.error = Text("", align="center")
         self.progress = Text("", align="center")
 
@@ -108,6 +122,9 @@ class IdentityView(BaseView):
                 self.error.set_text("Creating user failed:\n" + result['err'])
                 return
             else:
+                # mark ourselves complete
+                mark_firstboot_complete()
+
                 data = json.loads(result['output'])
                 result = {
                     'realname': self.email.value,
