@@ -17,7 +17,9 @@ import errno
 import ipaddress
 import logging
 import os
+
 import netifaces
+
 from subiquitycore.prober import make_network_info
 from subiquitycore.model import BaseModel
 from subiquitycore.utils import (read_sys_net,
@@ -43,6 +45,8 @@ class Networkdev():
         self.search_domains = []
         self.nameservers = []
         self.gateway = None
+        self.essid = None
+        self.wpa_psk = None
 
     def configure(self, probe_info=None):
         log.debug('Configuring iface {}'.format(self.ifname))
@@ -53,6 +57,9 @@ class Networkdev():
     def configure_from_info(self):
         log.debug('configuring netdev from info source')
 
+        if self.iftype == 'wlan':
+            self.essid = self.probe_info.raw['essid']
+
         ip_info = self.probe_info.ip
 
         sources = ip_info.get('sources', None)
@@ -100,9 +107,9 @@ class Networkdev():
     def render(self):
         log.debug("render to YAML")
         result = { self.ifname:
-                   { 
+                   {
                      'addresses': self.ipv4_addresses + self.ipv6_addresses,
-                   } 
+                   }
                  }
 
         if self.dhcp4:
@@ -113,6 +120,16 @@ class Networkdev():
         if self.iftype == 'bond':
             result[self.ifname]['interfaces'] = self.probe_info.bond['slaves']
 
+        if self.iftype == 'wlan':
+            if self.essid is None:
+                return {}
+            aps = result[self.ifname]['access-points'] = {}
+            ap = aps[self.essid] = {
+                'mode': 'infrastructure',
+                }
+            if self.wpa_psk is not None:
+                ap['password'] = self.wpa_psk
+
         return result
 
     @property
@@ -213,6 +230,9 @@ class Networkdev():
         ip_info = self._get_ip_info()
         return ip_info['ip6_providers']
 
+    def is_connected(self):
+        return self.probe_info.is_connected
+
     def remove_networks(self):
         self.remove_ipv4_networks()
         self.remove_ipv6_networks()
@@ -284,7 +304,10 @@ class NetworkModel(BaseModel):
          'network_configure_interface'),
         ('Network configure ipv4 interface',
          base_signal + ':configure-ipv4-interface',
-         'network_configure_ipv4_interface')
+         'network_configure_ipv4_interface'),
+        ('Network configure wlan interface',
+         base_signal + ':configure-wlan-interface',
+         'network_configure_wlan_interface'),
     ]
 
     additional_options = [
@@ -342,6 +365,7 @@ class NetworkModel(BaseModel):
     # --- Model Methods ----
     def probe_network(self):
         log.debug('model calling prober.get_network()')
+        self.prober.probe()
         network_devices = self.prober.get_network_devices()
         self.network_routes = self.prober.get_network_routes()
 
@@ -640,15 +664,23 @@ class NetworkModel(BaseModel):
                  }
         ethernets = {}
         bonds = {}
+        wifis = {}
         for iface in self.devices.values():
             if iface.iftype == 'eth':
                 ethernets.update(iface.render())
             if iface.iftype == 'bond':
                 bonds.update(iface.render())
+            if iface.iftype == 'wlan':
+                if len(iface.ipv4_addresses) > 0 \
+                        or len(iface.ipv6_addresses) > 0 \
+                        or iface.dhcp4 or iface.dhcp6: 
+                    wifis.update(iface.render())
         if any(ethernets):
             config['network']['ethernets'] = ethernets
         if any(bonds):
             config['network']['bonds'] = bonds
+        if any(wifis):
+            config['network']['wifis'] = wifis
 
         routes = self.get_default_route()
         nw_routes = []
